@@ -1,5 +1,6 @@
 from moto import mock_dynamodb2
 from pytest import fixture
+from pathlib import Path
 
 
 @fixture
@@ -15,7 +16,7 @@ def os_env():
 def test_main(os_env):
     from dynamo_db_resource.__main__ import create_table_for_schema_in_directory
 
-    directory = "./test_data/tables"
+    directory = Path(Path(__file__).parent, "test_data/tables")
     tables = ["TableForTest"]
 
     create_table_for_schema_in_directory(directory, tables)
